<template>
  <div class="launch-bg" id="launch-bg">
    <mt-header fixed :title="appTitle" class="launch"> 
      <!-- <router-link to="/flowcenter" slot="left">
        <mt-button icon="back"></mt-button>
      </router-link> -->
      <mt-button icon="back" slot="left" @click="doBack"></mt-button>
    </mt-header>
    <div class="spaceHeader"></div>
    <div v-for="mode in modes" :key="mode.id" class="launchCon">
      <div class="launchConBox">
        <div class v-if="findLaunchMenus(mode.id).length>0">
          <div  class="launch-partHeader">{{mode.description}}</div>
          <div class="launch-flex">
            <template v-for="(menu, index) in findLaunchMenus(mode.id)">
              <!-- :to="{name:'open', query:{linkType:'00',actionContent:menu.formId}}" -->
              <router-link
                to="/launch"
                @click.native="nav_click(menu.formId, menu)"
                :key="index"
              >
                <div :key="menu.id" class="launch-flexSpan">
                  <div v-if="menu.ico != null && menu.ico.icontype == 'img'" class="icon-wrap">
                    <img class="menu-img" :src="contextPath + menu.ico.icon + aToken" />
                  </div>
                  <div v-if="menu.ico != null && menu.ico.icontype == 'font'" class="icon-wrap">
                    <i :class="'menu-font fa-2x '+ menu.ico.icon" :style="{color: menu.ico.iconFontColor}"></i>
                  </div>
                  <div v-if="menu.ico == null" class="icon-wrap">
                    <img class="menu-img" src="../assets/images/defaultMenu.png"/>
                  </div>
                  <span class="description">{{menu.description}}</span>
                </div>
              </router-link>
            </template>
          </div>
        </div>
      </div>
    </div>
  </div>
</template>

<script>
import { Toast } from 'mint-ui';
import API from "@/api.js";
import Constant from "@/Constant.js";
export default {
  name: "launch",
  created() {
    this.aToken = "?accessToken=" + localStorage.getItem("accessToken")
    this.contextPath = obpmConfig.obpmFilePath;
    API.getStartMenus(this.$root.appid, {
      onSucess: response => {
        this.startmenus = response.data.data;
      }
    });
  },
  activated() {
    let positionY = this.$store.state.scrollY
    let scrollId = document.getElementById("launch-bg")
    if( positionY === 0 ) {
      scrollId.scrollTo(0, 0)
    }else {
      scrollId.scrollTo(0, positionY) //页面激活时控制滚动条滚动到指定的位置
    }
  },
  beforeRouteLeave(to, from, next) {
    from.meta.keepAlive = true;
    let scrollY = document.getElementById("launch-bg").scrollTop //离开之前记录此时滚动条的位置
    this.$store.commit('saveScrollY', scrollY)
    next();
  },
  data: function() {
    return {
      startmenus: [],
      Constant,
      contextPath: "",
      appTitle:'',
      aToken:'',
    };
  },
  mounted(){
    this.appTitle=document.title
  },
  methods: {
    doBack() {
      this.$router.go(-1)
    },

    nav_click(formId, menu) {
      let appId = this.$root.appid;
      let params = {
        linkType:'00',
        actionContent:formId
      };
      if(menu.queryString) {
        params.queryString = menu.queryString;
      }
      this.$api.hasPermissionToForm(appId, formId, {
        onSucess: response => {
          if(response.data.data) {
            this.$router.push({  
              name: 'open',
              query: params,
            })
          }else {
            Toast(this.$t('notPermission'))
          }
        }
      })
    },
    findLaunchMenus(modeid) {
      let menus = [];
      this.findSubMenus(modeid).forEach(menu => {
        if (menu.formId && menu.formId != "") {
          menus.push(menu);
        }
      });
      return menus;
    },

    findSubMenus(modeid) {
      let menus = [];
      if (this.startmenus)
        this.startmenus.forEach(menu => {
          if (menu.parent == modeid) {
            menus.push(menu);
          }
        });

      if (menus.length > 0) {
        menus.forEach(menu => {
          let submenus = this.findSubMenus(menu.id);
          menus = menus.concat(submenus);
        });
      }
      //console.log("modes-->",menus)
      return menus;
    }
  },

  computed: {
    modes() {
      let modes = [];
      if (this.startmenus)
        this.startmenus.forEach(menu => {
          if (menu.parent == this.$root.appid) {
            modes.push({
              id: menu.id,
              description: menu.description
            });
          }
        });
      return modes;
    } 
  }
};
</script>